==> moru_payment_gateway-0.2.5.tar.gz: lib/example/main.dart <==
import 'package:flutter/material.dart';
import 'package:moru_payment_gateway/moru_payment_gateway.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Moru Payment Gateway',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(),
    );
  }
}

class MyHomePage extends StatefulWidget {
  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final String accessKey =
      'b4856fab37c347038c31d8239f8c2157ab1421e50563489c9acec0cba073b637';

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('Moru Payment Gateway'),
        ),
        body: Padding(
          padding: const EdgeInsets.all(15.0),
          child: Center(
            child: Column(
              children: [
                Image.asset(
                  'assets/images/logo.png',
                  width: 100,
                  filterQuality: FilterQuality.high,
                ),
                SizedBox(
                  height: 20,
                ),
                Container(
                  height: 50,
                  color: Colors.grey[200],
                  child: Center(
                      child: Text(
                    "Total Amount: Rs.200",
                    style: TextStyle(fontWeight: FontWeight.w500, fontSize: 16),
                  )),
                ),
                SizedBox(
                  height: 20,
                ),
                MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: MediaQuery.of(context).size.width,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 48,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () {

                  final Widget widdget=  MoruPaymentSDK.builder(accessKey: accessKey, amount: 123)
                        .withAdditionalData(
                            additionalData: {'daraz': 'ITEM-44'})
                        .withProductIdentifier(identifier: 'snap-dragon')
                        .build()
                        .launch();

                  Navigator.of(context).push(MaterialPageRoute(builder: (context)=>widdget));
                  },
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "BUY NOW",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
                const SizedBox(
                  height: 20,
                ),
              ],
            ),
          ),
        ));
  }
}

==> moru_payment_gateway-0.2.9.tar.gz: lib/example/main.dart <==
import 'package:flutter/material.dart';
import 'package:moru_payment_gateway/moru_payment_gateway.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Moru Payment Gateway',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(),
    );
  }
}

class MyHomePage extends StatefulWidget {
  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final String accessKey =
      'test_a33173ce922a4971968a6c1bf59a4aa4b88a3521c2e640feb7c3ce91e82320f8';

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('Moru Payment Gateway'),
        ),
        body: Padding(
          padding: const EdgeInsets.all(15.0),
          child: Center(
            child: Column(
              children: [
                Image.asset(
                  'assets/images/logo.png',
                  width: 100,
                  filterQuality: FilterQuality.high,
                ),
                SizedBox(
                  height: 20,
                ),
                Container(
                  height: 50,
                  color: Colors.grey[200],
                  child: Center(
                      child: Text(
                    "Total Amount: Rs.100",
                    style: TextStyle(fontWeight: FontWeight.w500, fontSize: 16),
                  )),
                ),
                SizedBox(
                  height: 20,
                ),
                MaterialButton(
                  color: Color(0xffC91F3D),
                  textColor: Colors.black,
                  minWidth: MediaQuery.of(context).size.width,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7),
                  ),
                  height: 48,
                  highlightColor: Colors.white30,
                  elevation: 0,
                  highlightElevation: 0,
                  onPressed: () async {
                    final Widget widget = MoruPaymentSDK.builder(
                            accessKey: accessKey, amount: 100)
                        .withAdditionalData(
                            additionalData: {'email': 'test@test.com'})
                        .withProductIdentifier(identifier: '123')
                        .build()
                        .launch(
                            checkoutListener: (checkoutStatus, statusResponse) {
                          print("$checkoutStatus");
                          print("${statusResponse.accessData!.moruTxnIdentifier}");
                        });

                    Navigator.of(context)
                        .push(MaterialPageRoute(builder: (context) => widget));
                  },
                  padding: EdgeInsets.all(12),
                  child: Text(
                    "BUY NOW",
                    style: TextStyle(
                        fontWeight: FontWeight.w800,
                        color: Colors.white,
                        fontSize: 14),
                  ),
                ),
                const SizedBox(
                  height: 20,
                ),
              ],
            ),
          ),
        ));
  }
}
